mater\_data\_providing.definitions
==================================

.. automodule:: mater_data_providing.definitions

   
   .. rubric:: Functions

   .. autosummary::
   
      metadata_definition
      provider_definition
   